@@ -3,8 +3,8 @@
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
-#ifndef breezeanimations_h
-#define breezeanimations_h
+
+#pragma once
 
 #include "breezebusyindicatorengine.h"
 #include "breezedialengine.h"
@@ -135,7 +135,7 @@ private:
     //* editable combobox arrow hover effect
     WidgetStateEngine *_comboBoxEngine = nullptr;
 
-    //* mennu toolbutton arrow hover effect
+    //* menu toolbutton arrow hover effect
     WidgetStateEngine *_toolButtonEngine = nullptr;
 
     //* item view engine
@@ -164,5 +164,3 @@ private:
 };
 
 }
-
-#endif
