@@ -204,8 +204,8 @@ MdiWindowShadow *MdiWindowShadowFactory::findShadow(QObject *object) const
     }
 
     // find existing window shadows
-    auto children = object->parent()->children();
-    foreach (QObject *child, children) {
+    const auto children = object->parent()->children();
+    for (QObject *child : children) {
         if (MdiWindowShadow *shadow = qobject_cast<MdiWindowShadow *>(child)) {
             if (shadow->widget() == object) {
                 return shadow;
